==> assertj-build-3.25.3.tar.gz: assertj-assertj-build-3.25.3/assertj-core/src/test/java/org/assertj/core/api/abstract_/AbstractAssert_describedAs_with_text_description_Test.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2024 the original author or authors.
 */
package org.assertj.core.api.abstract_;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.test.TestData.someTextDescription;

import org.assertj.core.api.AbstractAssert;
import org.assertj.core.api.ConcreteAssert;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

/**
 * Tests for <code>{@link AbstractAssert#describedAs(String)}</code>.
 * 
 * @author Alex Ruiz
 */
class AbstractAssert_describedAs_with_text_description_Test {

  private ConcreteAssert assertions;
  private String description;

  @BeforeEach
  void setUp() {
    assertions = new ConcreteAssert(6L);
    description = someTextDescription();
  }

  @Test
  void should_set_description() {
    assertions.describedAs(description);
    assertThat(assertions.descriptionText()).isEqualTo(description);
  }

  @Test
  void should_return_this() {
    ConcreteAssert descriptable = assertions.describedAs(description);
    assertThat(descriptable).isSameAs(assertions);
  }

  @Test
  void should_set_empty_description_if_description_is_null() {
    String description = null;
    assertions.describedAs(description);
    assertThat(assertions.descriptionText()).isEmpty();
  }
}

==> assertj-build-3.27.6.tar.gz: assertj-assertj-build-3.27.6/assertj-core/src/test/java/org/assertj/core/api/abstract_/AbstractAssert_describedAs_with_text_description_Test.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2025 the original author or authors.
 */
package org.assertj.core.api.abstract_;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.testkit.TestData.someTextDescription;

import org.assertj.core.api.AbstractAssert;
import org.assertj.core.api.ConcreteAssert;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

/**
 * Tests for <code>{@link AbstractAssert#describedAs(String)}</code>.
 * 
 * @author Alex Ruiz
 */
class AbstractAssert_describedAs_with_text_description_Test {

  private ConcreteAssert assertions;
  private String description;

  @BeforeEach
  void setUp() {
    assertions = new ConcreteAssert(6L);
    description = someTextDescription();
  }

  @Test
  void should_set_description() {
    assertions.describedAs(description);
    assertThat(assertions.descriptionText()).isEqualTo(description);
  }

  @Test
  void should_return_this() {
    ConcreteAssert descriptable = assertions.describedAs(description);
    assertThat(descriptable).isSameAs(assertions);
  }

  @Test
  void should_set_empty_description_if_description_is_null() {
    String description = null;
    assertions.describedAs(description);
    assertThat(assertions.descriptionText()).isEmpty();
  }
}
